/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 997 $
 * $Date: 2020-03-19 13:49:34 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.general.math.autodiff;

/**
 * Power function
 * 
 * @author Gnther Weidenholzer
 * @author Werner Koppelsttter
 */
public class Pow extends Func {

	/** Exponent */
	private double p;

	/**
	 * Create power of argument with exponent
	 * 
	 * @param arg
	 *            Argument of power
	 * @param p
	 *            Exponent of power
	 */
	public Pow(Func arg, double p) {
		super(arg);
		this.p = p;
	}

	@Override
	public double value() throws Exception {
		return Math.pow(this.getArg(0).value(), this.p);
	}

	/**
	 * Derivation of power
	 * 
	 * @param arg
	 *            Argument for derivative
	 * @return Derivative function
	 * @throws Exception
	 *             Derivative exception
	 */
	@Override
	public Func derivativeArg(Func arg) throws Exception {

		return new Product(new Constant(this.p),
				new Pow(this.getArg(0), this.p - 1));

	}

	@Override
	public String toString() {
		String str;

		str = "(";
		try {
			str += this.getArg(0).toString();
		} catch (Exception e) {
			str += "'?'";
		}
		str += "^";
		str += this.p;
		str += ")";

		return str;
	}

}
