/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 997 $
 * $Date: 2020-03-19 13:49:34 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.general.plot;

/**
 * Enumeration for hold-states
 * 
 * @author Christoph Halbmayr
 * @author Werner Koppelsttter
 */
public enum HOLD {
	/**
	 * hold all holds the plot and the current line color and line style so that
	 * subsequent plotting commands do not reset the ColorOrder and ColorOrder
	 * property values to the beginning of the list. Plotting commands continue
	 * cycling through the predefined colors and linestyles from where the last
	 * plot stopped in the list
	 */
	ALL,
	/**
	 * fades the line colors, the last added signal has the best contrast. only
	 * the last added signal is enabled
	 */
	FADING,
	/**
	 * hold off resets axes properties to their defaults before drawing new
	 * plots. hold off is the default.
	 */
	OFF,
	/**
	 * hold on retains the current plot and certain axes properties so that
	 * subsequent graphing commands add to the existing graph.
	 */
	ON;
}
