from lxml import etree

from dtypes import tnull, tstruct, tarray, tnumeric, tboolean, tperiodic, tperiodicmatrix, tstring

from dtypes import TData

def fromString(s):
    tree= etree.fromstring(s)
    return fromnode(tree)    

def toString(obj):
    tree = etree.ElementTree(obj.data2xml())
    tmp=etree.tostring(tree, encoding='utf-8', xml_declaration=True)
    return tmp.decode("utf-8")

def readfile(src):
    tree = etree.parse(src)
    root = tree.getroot()    
    return fromnode(root)
    
    
def writefile(node, dest):
    tree = etree.ElementTree(node.data2xml())
    tree.write(dest, encoding='utf-8', xml_declaration=True) 

def fromnode(node):
    
    tag=node.tag.lower()
   
    if tag == "null":
        return tnull.TNull()
        
    elif tag == "struct":
        return tstruct.TStruct.fromXML(node)
        
    elif tag == "array":
        return tarray.TArray.fromXML(node)
    
    elif tag == "string":
        return tstring.TString.fromXML(node)
        
    elif tag == "numeric":
        return tnumeric.TNumeric.fromXML(node)
        
    elif tag == "boolean":
        return tboolean.TBoolean.fromXML(node)
        
    elif tag == "periodic":
        return tperiodic.TPeriodic.fromXML(node)
        
    elif tag == "periodicmatrix":
        return tperiodicmatrix.TPeriodicMatrix.fromXML(node)
        
    else:
        raise Exception("type '"+ node.tag + "' is not defined!")
               

def toTData(value):
    
    if value is None:
        return tnull.TNull()
        
    elif isinstance(value, TData):        
        return value
        
    elif isinstance(value, str):
        return tstring.TString(value)
        
    elif isinstance(value, bool):
        return tboolean.TBoolean(value)
        
    elif isinstance(value, dict):
        return tstruct.TStruct(value)   
        
    else:
        try:
            num=tnumeric.TNumeric(value)
            return num
        except TypeError:
            raise Exception("cannot convert to TData type!")

               