#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 977 $
$LastChangedDate:: 2019-12-11 15:24:14 +0100#$

This file is part of SyMSpace.

Copyright (c) 2019, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""
import numpy as np
from abc import ABCMeta
from abc import abstractmethod
from lcm.tdata_interface.pyjdata_interface import PyJDataInterface

'''java imports'''
# noinspection PyUnresolvedReferences
from at.lcm.bu21.general.math.interpolator2d import Interpolator2d as JInterpolator2d
# noinspection PyUnresolvedReferences
from at.lcm.bu21.general.math.interpolator2d import RbfInt2d as JRbfInt2d
# noinspection PyUnresolvedReferences
from at.lcm.bu21.general.math.interpolator2d import DelaunayInt2d as JDelaunayInt2d


class Interpolator2d(metaclass=ABCMeta):
    JClass = JInterpolator2d

    def __init__(self, xdata: np.ndarray, ydata: np.ndarray, zdata: np.ndarray):
        jxdata = PyJDataInterface.convert_Py2J(xdata)
        jydata = PyJDataInterface.convert_Py2J(ydata)
        jzdata = PyJDataInterface.convert_Py2J(zdata)
        self.jobj = self.JClass(jxdata, jydata, jzdata)

    def value(self, x: float, y: float):
        jval = self.jobj.value(x, y)
        val = PyJDataInterface.convert_J2Py(jval)
        return val


class RbfIn2d(Interpolator2d):
    JClass = JRbfInt2d


class DelaunayInt2d(Interpolator2d):
    JClass = JDelaunayInt2d

