/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9715 $
 * $Date: 2020-03-19 10:01:15 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.symspace.center.views;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.net.URL;

import javax.swing.ImageIcon;
import javax.swing.JButton;

import at.lcm.symspace.center.CenterController;
import at.lcm.symspace.center.icons.IconToolbar;
import at.lcm.symspace.gui.views.ToolBar;

public class CenterToolBar extends ToolBar implements ActionListener {

	private static String ACTION_NEW = "New";
	private static String ACTION_OPEN = "Open";
	private static String ACTION_SAVE = "Save";

	private static String ACTION_CUT_PARAMETER = "Cut parameter";
	private static String ACTION_COPY_PARAMETER = "Copy parameter";
	private static String ACTION_PASTE_PARAMETER = "Paste parameter";

	private static String ACTION_REFRESH = "Refresh";
	private static String ACTION_CHECK = "Check";
	private static String ACTION_REGENERATE = "Regenerate";

	private static String ACTION_DUPLICATE = "Duplicate";
	private static String ACTION_REDUCE = "Reduce";

	private static String ACTION_JOBMANAGER = "JobManager";

	private static String ACTION_MACRO = "Run macro";

	CenterController controller;

	JButton tbNew;
	JButton tbOpen;
	JButton tbSave;

	JButton tbCut;
	JButton tbCopy;
	JButton tbPaste;

	JButton tbRegenerate;
	JButton tbCheck;
	JButton tbRefresh;

	JButton tbDuplicate;
	JButton tbReduce;

	JButton tbJobManager;

	JButton tbMacro;

	public CenterToolBar(CenterController controller) {
		this.controller = controller;

		this.tbNew = this.makeNavigationButton(IconToolbar.NEW, CenterToolBar.ACTION_NEW, "New", "New");
		this.add(this.tbNew);
		this.tbOpen = this.makeNavigationButton(IconToolbar.OPEN, CenterToolBar.ACTION_OPEN, "Open", "Open");
		this.add(this.tbOpen);
		this.tbSave = this.makeNavigationButton(IconToolbar.SAVE, CenterToolBar.ACTION_SAVE, "Save", "Save");
		this.add(this.tbSave);

		this.addSeparator();

		this.tbCut = this.makeNavigationButton(IconToolbar.CUT, CenterToolBar.ACTION_CUT_PARAMETER, "Cut", "Cut");
		this.add(this.tbCut);
		this.tbCopy = this.makeNavigationButton(IconToolbar.COPY, CenterToolBar.ACTION_COPY_PARAMETER, "Copy", "Copy");
		this.add(this.tbCopy);
		this.tbPaste = this.makeNavigationButton(IconToolbar.PASTE, CenterToolBar.ACTION_PASTE_PARAMETER, "Paste",
				"Paste");
		this.add(this.tbPaste);

		this.addSeparator();

		this.tbRegenerate = this.makeNavigationButton(IconToolbar.REGENERATE, CenterToolBar.ACTION_REGENERATE,
				"Regenerate", "Regenerate");
		this.add(this.tbRegenerate);
		this.tbCheck = this.makeNavigationButton(IconToolbar.CHECK, CenterToolBar.ACTION_CHECK, "Check", "Check");
		this.add(this.tbCheck);
		this.tbRefresh = this.makeNavigationButton(IconToolbar.REFRESH, CenterToolBar.ACTION_REFRESH, "Refresh",
				"Refresh");
		this.add(this.tbRefresh);

		this.addSeparator();

		this.tbDuplicate = this.makeNavigationButton(IconToolbar.DUPLICATE, CenterToolBar.ACTION_DUPLICATE, "Duplicate",
				"Duplicate");
		this.add(this.tbDuplicate);
		this.tbReduce = this.makeNavigationButton(IconToolbar.REDUCE, CenterToolBar.ACTION_REDUCE, "Reduce", "Reduce");
		this.add(this.tbReduce);

		this.addSeparator();

		this.tbJobManager = this.makeNavigationButton(IconToolbar.JOBMANAGER, CenterToolBar.ACTION_JOBMANAGER,
				"Open JobManager", "OpenJobManager");
		this.add(this.tbJobManager);

		this.tbMacro = this.makeNavigationButton(IconToolbar.MACRO, CenterToolBar.ACTION_MACRO, "Run macro",
				"Run macro");
		this.add(this.tbMacro);

		// FIXME
		// this.add(this.makeNavigationButton(IconToolbar.ICON_, "Optimizer",
		// "Optimizer", "Optimizer"));

		// FIXME Excel
		// FIXME Component
	}

	private JButton makeNavigationButton(URL icon, String actionCommand, String toolTipText, String altText) {
		JButton button;

		button = new JButton();
		button.setEnabled(false);
		button.setActionCommand(actionCommand);
		button.setToolTipText(toolTipText);
		button.addActionListener(this);

		if (icon != null) {
			try {
				button.setIcon(new ImageIcon(icon));
			} catch (Exception e) {
				button.setText(altText);
			}
		} else {
			button.setText(altText);

		}

		return button;
	}

	@Override
	public void actionPerformed(ActionEvent e) {
		if (e.getActionCommand() == CenterToolBar.ACTION_NEW) {
			this.controller.mnu_file_new();
		} else if (e.getActionCommand() == CenterToolBar.ACTION_OPEN) {
			this.controller.mnu_file_open();
		} else if (e.getActionCommand() == CenterToolBar.ACTION_SAVE) {
			this.controller.mnu_file_save();
		} else if (e.getActionCommand() == CenterToolBar.ACTION_CUT_PARAMETER) {
			this.controller.mnu_edit_cut_parameter();
		} else if (e.getActionCommand() == CenterToolBar.ACTION_COPY_PARAMETER) {
			this.controller.mnu_edit_copy_parameter();
		} else if (e.getActionCommand() == CenterToolBar.ACTION_PASTE_PARAMETER) {
			this.controller.mnu_edit_paste_parameter();
		} else if (e.getActionCommand() == CenterToolBar.ACTION_REFRESH) {
			this.controller.mnu_update_refresh();
		} else if (e.getActionCommand() == CenterToolBar.ACTION_CHECK) {
			this.controller.mnu_update_check();
		} else if (e.getActionCommand() == CenterToolBar.ACTION_REGENERATE) {
			this.controller.mnu_update_regenerate();
		} else if (e.getActionCommand() == CenterToolBar.ACTION_DUPLICATE) {
			this.controller.mnu_edit_duplicate();
		} else if (e.getActionCommand() == CenterToolBar.ACTION_REDUCE) {
			this.controller.mnu_edit_reduce();
		} else if (e.getActionCommand() == CenterToolBar.ACTION_JOBMANAGER) {
			this.controller.mnu_update_jobmanager();
		} else if (e.getActionCommand() == CenterToolBar.ACTION_MACRO) {
			this.controller.mnu_update_macro();
		} else {
			System.out.println("Not implemented");
		}
	}

	@Override
	public void refresh() {
		boolean enabled = this.isEnabled();
		boolean projectExist = enabled && (this.controller.getProject() != null);

		// FIXME dirty
		this.tbNew.setEnabled(enabled);
		this.tbOpen.setEnabled(enabled);
		this.tbSave.setEnabled(projectExist);
		this.tbCut.setEnabled(projectExist);
		this.tbCopy.setEnabled(projectExist);
		this.tbPaste.setEnabled(projectExist);
		this.tbRegenerate.setEnabled(projectExist);
		this.tbCheck.setEnabled(projectExist);
		this.tbRefresh.setEnabled(enabled);
		this.tbDuplicate.setEnabled(projectExist);
		this.tbReduce.setEnabled(projectExist);
		this.tbJobManager.setEnabled(enabled);
		this.tbMacro.setEnabled(enabled);
	}

	@Override
	public void setEnabled(boolean aFlag) {
		super.setEnabled(aFlag);
		this.refresh();
	}
}
