/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9715 $
 * $Date: 2020-03-19 10:01:15 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.symspace.center.views.indices;

import java.awt.Color;
import java.awt.Font;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.util.Timer;
import java.util.TimerTask;

import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JTextField;

public class IndexViewDialog extends JDialog {
	/**
	 * 
	 */
	private static final long serialVersionUID = 19700717201307241L;
	private JTextField textField;
	private boolean _useInput = false;

	/**
	 * Create the dialog.
	 */
	public IndexViewDialog() {
		this.setModal(true);
		this.setTitle("Index comparison");
		this.setBounds(100, 100, 320, 230);
		this.setResizable(false);
		GridBagLayout gridBagLayout = new GridBagLayout();

		this.getContentPane().setLayout(gridBagLayout);

		this.textField = new JTextField();
		this.textField.addKeyListener(new KeyAdapter() {
			@Override
			public void keyPressed(KeyEvent evt) {
				if (evt.getKeyCode() == KeyEvent.VK_ENTER) {
					// Enter was pressed.
					IndexViewDialog.this._useInput = true;
					IndexViewDialog.this.setVisible(false);
				}
			}
		});
		GridBagConstraints gbc_textField = new GridBagConstraints();
		gbc_textField.fill = GridBagConstraints.HORIZONTAL;
		gbc_textField.weightx = 1.0;
		gbc_textField.anchor = GridBagConstraints.WEST;
		gbc_textField.gridwidth = 2;
		gbc_textField.gridx = 1;
		gbc_textField.gridy = 1;
		this.getContentPane().add(this.textField, gbc_textField);
		this.textField.setColumns(10);

		JLabel lblNewLabel = new JLabel("Please add an index to compare!");
		lblNewLabel.setFont(new Font("Tahoma", Font.PLAIN, 15));
		lblNewLabel.setBackground(Color.WHITE);
		GridBagConstraints gbc_lblNewLabel = new GridBagConstraints();
		gbc_lblNewLabel.weighty = 1.0;
		gbc_lblNewLabel.insets = new Insets(20, 0, 50, 0);
		gbc_lblNewLabel.gridwidth = 5;
		gbc_lblNewLabel.gridx = 0;
		gbc_lblNewLabel.gridy = 0;
		this.getContentPane().add(lblNewLabel, gbc_lblNewLabel);

		JLabel lblIndex = new JLabel("Index:");
		lblIndex.setFont(new Font("Tahoma", Font.PLAIN, 13));
		GridBagConstraints gbc_lblIndex = new GridBagConstraints();
		gbc_lblIndex.anchor = GridBagConstraints.LINE_START;
		gbc_lblIndex.insets = new Insets(0, 20, 0, 5);
		gbc_lblIndex.gridx = 0;
		gbc_lblIndex.gridy = 1;
		this.getContentPane().add(lblIndex, gbc_lblIndex);

		JButton btnOk = new JButton("OK");
		btnOk.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent arg0) {
				IndexViewDialog.this._useInput = true;
				System.out.println("OK");
				IndexViewDialog.this.setVisible(false);
			}
		});
		btnOk.setFont(new Font("Tahoma", Font.PLAIN, 13));
		GridBagConstraints gbc_btnOk = new GridBagConstraints();
		gbc_btnOk.anchor = GridBagConstraints.PAGE_END;
		gbc_btnOk.insets = new Insets(30, 0, 20, 5);
		gbc_btnOk.gridx = 3;
		gbc_btnOk.gridy = 2;
		this.getContentPane().add(btnOk, gbc_btnOk);

		JButton btnNewButton = new JButton("Cancel");
		btnNewButton.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				IndexViewDialog.this._useInput = false;
				System.out.println("Cancel");
				IndexViewDialog.this.setVisible(false);

			}
		});
		btnNewButton.setFont(new Font("Tahoma", Font.PLAIN, 13));
		GridBagConstraints gbc_btnNewButton = new GridBagConstraints();
		gbc_btnNewButton.anchor = GridBagConstraints.LAST_LINE_END;
		gbc_btnNewButton.insets = new Insets(30, 5, 20, 20);
		gbc_btnNewButton.gridx = 4;
		gbc_btnNewButton.gridy = 2;
		this.getContentPane().add(btnNewButton, gbc_btnNewButton);

		// request focus after 200ms
		new Timer().schedule(new TimerTask() {
			@Override
			public void run() {
				IndexViewDialog.this.textField.requestFocus();
			}
		}, 500, Long.MAX_VALUE);
	}

	@Override
	public void setVisible(boolean flag) {

		super.setVisible(flag);
		if (flag == true) {
			this.textField.requestFocus(); // funktioniert nicht
		}
	}

	public boolean useInput() {

		return this._useInput;
	}

	public String getInput() {

		return this.textField.getText();
	}
}
