/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9715 $
 * $Date: 2020-03-19 10:01:15 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.symspace.center.views.tree;

import java.awt.BorderLayout;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.util.LinkedList;

import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.SwingUtilities;
import javax.swing.event.TreeModelEvent;
import javax.swing.event.TreeModelListener;
import javax.swing.tree.TreePath;

import at.lcm.bu21.magopt.structure.IParamContainer;
import at.lcm.bu21.magopt.structure.ParamContainer;
import at.lcm.bu21.magopt.structure.Parameter;
import at.lcm.bu21.magopt.structure.Project;
import at.lcm.symspace.center.views.CenterViewManager;

/**
 * View panel for value comparison in magopt GUI. Displays the structure as DnD
 * tree and the values in a table
 * 
 * @author Markus Priglinger
 * @author Werner Koppelsttter
 */

public class StructureViewPanel extends JPanel { // implements ViewPanelListener
													// ,
													// ParamListener,
													// DropTargetListener
													// {

	/** Serialization version number */
	private static final long serialVersionUID = 19700717201308151L;

	private CenterViewManager views;

	private Project _project = null;

	// / Tree model
	private DnDTreeForTable _tree = null;

	private ProTreeTable _treeTable = null;
	private JScrollPane _scrollPane = null;
	private ProParameterModel _model = null;

	ProTreeTableIndexViewManager ivm;

	public StructureViewPanel(CenterViewManager views) {
		this.views = views;
		// listen to GUI manager
		// XXX ???
		// GUIManager.getInstance().addViewPanelListener(this);

		this.setLayout(new BorderLayout());

		this._model = new ProParameterModel(this._project);
		// XXX ???
		// this._model.addTreeModelListener(GUIManager.getInstance());
		this._model.addTreeModelListener(new TreeModelListener() {

			@Override
			public void treeStructureChanged(TreeModelEvent e) {
				StructureViewPanel.this.views.refresh();
			}

			@Override
			public void treeNodesRemoved(TreeModelEvent e) {

			}

			@Override
			public void treeNodesInserted(TreeModelEvent e) {

			}

			@Override
			public void treeNodesChanged(TreeModelEvent e) {
				StructureViewPanel.this.views.refresh();
			}
		});

		this._treeTable = new ProTreeTable(this._model);

		this._treeTable.setProParameterModel(this._model);

		this._treeTable.addMouseListener(new MouseAdapter() {

			@Override
			public void mouseReleased(MouseEvent e) {
				Parameter selectedParameter = StructureViewPanel.this._treeTable.getSelectedParameter();
				// GUIManager.getInstance()
				// .setSelectedParameter(selectedParameter);
				StructureViewPanel.this.views.getController().setSelected(selectedParameter);
			}
		});

		this._treeTable.addKeyListener(new KeyAdapter() {

			@Override
			public void keyReleased(KeyEvent event) {
				TreePath path;
				Parameter param;

				switch (event.getKeyCode()) {
				// case KeyEvent.VK_UP:
				// case KeyEvent.VK_DOWN:
				// Parameter selectedParameter =
				// StructureViewPanel.this._treeTable
				// .getSelectedParameter();
				// // GUIManager.getInstance()
				// // .setSelectedParameter(selectedParameter);
				// StructureViewPanel.this.views.getController()
				// .setSelected(selectedParameter);
				// break;
				case KeyEvent.VK_LEFT:
					path = StructureViewPanel.this._tree.getSelectionPath();
					if (StructureViewPanel.this._tree.isExpanded(path)) {
						StructureViewPanel.this._tree.collapsePath(path);
					} else {
						if (path.getParentPath() != null) {
							path = path.getParentPath();
						}
					}
					StructureViewPanel.this._tree.setSelectionPath(path);
					break;
				case KeyEvent.VK_RIGHT:
					path = StructureViewPanel.this._tree.getSelectionPath();
					if (StructureViewPanel.this._tree.isExpanded(path)) {
						param = StructureViewPanel.this._treeTable.getSelectedParameter();
						if ((param instanceof IParamContainer) && (((ParamContainer) param).getParamSize() > 0)) {
							StructureViewPanel.this._tree
									.setSelectionRow(StructureViewPanel.this._treeTable.getSelectedRow() + 1);
							path = StructureViewPanel.this._tree.getSelectionPath();
						}
					} else {
						StructureViewPanel.this._tree.expandPath(path);
					}
					StructureViewPanel.this._tree.setSelectionPath(path);
					break;
				default:
					Parameter selectedParameter = StructureViewPanel.this._treeTable.getSelectedParameter();
					StructureViewPanel.this.views.getController().setSelected(selectedParameter);

					break;
				}
			}
		});

		this._tree = this._treeTable.getTree();
		this._tree.setSelectionRow(0);

		this._scrollPane = new JScrollPane(this._treeTable);
		// this._scrollPane.getViewport().setBackground(Color.white);
		this.add(this._scrollPane);

	}

	public void setProject(Project project) {
		this._project = project;

		this._model.setRoot(this._project);
		if (this._project != null) {
			this._treeTable.setSelectedIndex(this._project.getIndex());
		}

		// if (this._project == null) {
		// this._scrollPane.setViewportView(new JTable());
		// } else {
		// this._model = new ProParameterModel(this._project);
		// // XXX ???
		// // this._model.addTreeModelListener(GUIManager.getInstance());
		// this._model.addTreeModelListener(new TreeModelListener() {
		//
		// @Override
		// public void treeStructureChanged(TreeModelEvent e) {
		// StructureViewPanel.this.views.refresh();
		// }
		//
		// @Override
		// public void treeNodesRemoved(TreeModelEvent e) {
		//
		// }
		//
		// @Override
		// public void treeNodesInserted(TreeModelEvent e) {
		//
		// }
		//
		// @Override
		// public void treeNodesChanged(TreeModelEvent e) {
		//
		// }
		// });
		//
		// this._treeTable = new ProTreeTable(this.views, this._model);
		//
		// this._treeTable.setProParameterModel(this._model);
		//
		// this._treeTable.addMouseListener(new MouseAdapter() {
		//
		// @Override
		// public void mouseReleased(MouseEvent e) {
		// Parameter selectedParameter = StructureViewPanel.this._treeTable
		// .getSelectedParameter();
		// // GUIManager.getInstance()
		// // .setSelectedParameter(selectedParameter);
		// StructureViewPanel.this.views.getController()
		// .setSelected(selectedParameter);
		// }
		// });
		//
		// this._treeTable.addKeyListener(new KeyAdapter() {
		//
		// @Override
		// public void keyReleased(KeyEvent event) {
		// TreePath path;
		// Parameter param;
		//
		// switch (event.getKeyCode()) {
		// case KeyEvent.VK_UP:
		// case KeyEvent.VK_DOWN:
		// Parameter selectedParameter = StructureViewPanel.this._treeTable
		// .getSelectedParameter();
		// // GUIManager.getInstance()
		// // .setSelectedParameter(selectedParameter);
		// StructureViewPanel.this.views.getController()
		// .setSelected(selectedParameter);
		// break;
		// case KeyEvent.VK_LEFT:
		// path = StructureViewPanel.this._tree.getSelectionPath();
		// if (StructureViewPanel.this._tree.isExpanded(path)) {
		// StructureViewPanel.this._tree.collapsePath(path);
		// } else {
		// if (path.getParentPath() != null) {
		// path = path.getParentPath();
		// }
		// }
		// StructureViewPanel.this._tree.setSelectionPath(path);
		// break;
		// case KeyEvent.VK_RIGHT:
		// path = StructureViewPanel.this._tree.getSelectionPath();
		// if (StructureViewPanel.this._tree.isExpanded(path)) {
		// param = StructureViewPanel.this._treeTable
		// .getSelectedParameter();
		// if ((param instanceof IParamContainer)
		// && (((ParamContainer) param)
		// .getParamSize() > 0)) {
		// StructureViewPanel.this._tree.setSelectionRow(
		// StructureViewPanel.this._treeTable
		// .getSelectedRow() + 1);
		// path = StructureViewPanel.this._tree
		// .getSelectionPath();
		// }
		// } else {
		// StructureViewPanel.this._tree.expandPath(path);
		// }
		// StructureViewPanel.this._tree.setSelectionPath(path);
		// break;
		// }
		// }
		// });
		//
		// // XXX ???
		// // GUIManager.getInstance()._treeTable = this._treeTable;
		//
		// this._tree.setSelectionRow(0);
		//
		// // XXX ???
		// // GUIManager.getInstance().setSelectedParameter(this._project);
		//
		// this._scrollPane.setViewportView(this._treeTable);
		// }
	}

	// /**
	// * Select node with given identifier
	// *
	// * @param identifier
	// * Identifier of node
	// */
	// public void selectNode(String identifier) {
	// Parameter param = null;
	//
	// if (this._project != null) {
	// param = this._project.getUniqueObject(identifier);
	// // GUIManager.getInstance().setSelectedParameter(param);
	// this.views.getController().setSelected(param);
	// }
	// }

	/**
	 * Select node with given identifier
	 * 
	 * @param param
	 *            Parameter to select
	 */
	public void selectNode(Parameter param, boolean expand) {

		LinkedList<Parameter> pathList = new LinkedList<Parameter>();
		TreePath path;

		while (param != null) {
			pathList.addFirst(param);
			param = param.getParent();
		}

		if (pathList.size() > 0) {
			path = new TreePath(pathList.toArray());
			this._tree.setSelectionPath(path);
			if (expand) {
				this._tree.expandPath(path);
			}
		}
	}

	public void refresh() {
		if (this._treeTable != null) {
			SwingUtilities.invokeLater(new Runnable() {
				@Override
				public void run() {
					// TODO IParameter
					StructureViewPanel.this.selectNode(
							(Parameter) StructureViewPanel.this.views.getController().getSelected(),
							StructureViewPanel.this.views.getController().getProject() == StructureViewPanel.this.views
									.getController().getSelected());

					StructureViewPanel.this._treeTable.updateUI();
					StructureViewPanel.this.updateUI();
				}
			});
		}
	}

	// // Interface ParamListener
	// @Override
	// public void parameterChanged() {
	//
	// this.refresh();
	// }
	//
	// @Override
	// public void viewPanelChanged() {
	// }
	//
	// @Override
	// public void updateViewPanel() {
	//
	// this.refresh();
	// }
	//
	// @Override
	// public void projectChanged(Project project) {
	//
	// if (this._project != project) {
	// this.setProject(project);
	// }
	// this.refresh();
	// }

	// @Override
	// public void dragEnter(DropTargetDragEvent dtde) {
	// }
	//
	// @Override
	// public void dragExit(DropTargetEvent dte) {
	// }
	//
	// @Override
	// public void dragOver(DropTargetDragEvent dtde) {
	// }
	//
	// @Override
	// public void drop(DropTargetDropEvent dtde) {
	// }
	//
	// @Override
	// public void dropActionChanged(DropTargetDragEvent dtde) {
	// }
}
