/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9715 $
 * $Date: 2020-03-19 10:01:15 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.symspace.optimizer.views;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.net.URL;

import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.SwingUtilities;

import at.lcm.symspace.gui.views.ToolBar;
import at.lcm.symspace.optimizer.OptimizerController;
import at.lcm.symspace.optimizer.icons.IconOptimizerToolbar;

public class OptimizerToolBar extends ToolBar implements ActionListener {

	private static String ACTION_WIZARD = "Wizard";

	private static String ACTION_REFRESH = "Refresh";
	private static String ACTION_JOBMANAGER = "JobManager";

	private static String ACTION_RUN = "Run";
	private static String ACTION_FINISH = "Finish";
	private static String ACTION_STOP = "Stop";

	private static String ACTION_INIT_BUFFER = "Init buffer";
	private static String ACTION_CLEAR_BUFFER = "Clear buffer";

	private static String ACTION_EXCEL = "Create excel";
	private static String ACTION_SELECT = "Select individium";

	private static String ACTION_ADD_PLOT = "Add plot";
	private static String ACTION_REMOVE_PLOT = "Remove plot";

	private static String ACTION_MAPPING_CREATE_ALL = "Create all";
	private static String ACTION_MAPPING_OPTIMIZE = "Optimize mapping";
	private static String ACTION_SENSITIVIT_SELECT = "Select sensitivity";

	OptimizerController controller;

	JButton tbWizard;

	JButton tbRefresh;
	JButton tbJobManager;

	JButton tbRun;
	JButton tbFinish;
	JButton tbStop;

	JButton tbInitializeBuffer;
	JButton tbClearBuffer;

	JButton tbCreateExcel;
	JButton tbSelect;

	JButton tbAddPlot;
	JButton tbRemovePlot;

	JButton tbMappingCreateAll;
	JButton tbMappingOptimize;
	JButton tbSensitivity;

	public OptimizerToolBar(OptimizerController controller) {
		this.controller = controller;

		this.tbWizard = this.makeNavigationButton(IconOptimizerToolbar.WIZARD, OptimizerToolBar.ACTION_WIZARD, "Wizard",
				"Wizard");
		this.add(this.tbWizard);

		this.addSeparator();

		this.tbRefresh = this.makeNavigationButton(IconOptimizerToolbar.REFRESH, OptimizerToolBar.ACTION_REFRESH,
				"Refresh", "Refresh");
		this.add(this.tbRefresh);
		this.tbJobManager = this.makeNavigationButton(IconOptimizerToolbar.JOBMANAGER,
				OptimizerToolBar.ACTION_JOBMANAGER, "Open JobManager", "OpenJobManager");
		this.add(this.tbJobManager);

		this.addSeparator();

		this.tbRun = this.makeNavigationButton(IconOptimizerToolbar.RUN, OptimizerToolBar.ACTION_RUN,
				"Run optimization", "Run");
		this.add(this.tbRun);

		this.tbFinish = this.makeNavigationButton(IconOptimizerToolbar.FINISH, OptimizerToolBar.ACTION_FINISH,
				"Finish optimization", "Finish");
		this.add(this.tbFinish);

		this.tbStop = this.makeNavigationButton(IconOptimizerToolbar.STOP, OptimizerToolBar.ACTION_STOP,
				"Stop optimization", "Stop");
		this.add(this.tbStop);

		this.addSeparator();

		this.tbInitializeBuffer = this.makeNavigationButton(IconOptimizerToolbar.INIT_BUFFER,
				OptimizerToolBar.ACTION_INIT_BUFFER, "Initialize buffer", "Init buffer");
		this.add(this.tbInitializeBuffer);
		this.tbClearBuffer = this.makeNavigationButton(IconOptimizerToolbar.CLEAR_BUFFER,
				OptimizerToolBar.ACTION_CLEAR_BUFFER, "Clear buffer", "Clear buffer");
		this.add(this.tbClearBuffer);

		this.addSeparator();

		this.tbCreateExcel = this.makeNavigationButton(IconOptimizerToolbar.EXCEL, OptimizerToolBar.ACTION_EXCEL,
				"Extract to Excel", "Excel");
		this.add(this.tbCreateExcel);
		this.tbSelect = this.makeNavigationButton(IconOptimizerToolbar.SELECT, OptimizerToolBar.ACTION_SELECT,
				"Select optimum", "Select");
		this.add(this.tbSelect);

		this.addSeparator();

		this.tbAddPlot = this.makeNavigationButton(IconOptimizerToolbar.ADD_PLOT, OptimizerToolBar.ACTION_ADD_PLOT,
				"Add plot", "Add");
		this.add(this.tbAddPlot);
		this.tbRemovePlot = this.makeNavigationButton(IconOptimizerToolbar.REMOVE_PLOT,
				OptimizerToolBar.ACTION_REMOVE_PLOT, "Remove plot", "Remove");
		this.add(this.tbRemovePlot);

		this.addSeparator();

		this.tbMappingCreateAll = this.makeNavigationButton(IconOptimizerToolbar.MAPPING_CREATE_ALL,
				OptimizerToolBar.ACTION_MAPPING_CREATE_ALL, "Create all mappings", "Create all");
		this.add(this.tbMappingCreateAll);
		this.tbMappingOptimize = this.makeNavigationButton(IconOptimizerToolbar.MAPPING_OPTIMIZE,
				OptimizerToolBar.ACTION_MAPPING_OPTIMIZE, "Optimize with mapping", "Optimize mapping");
		this.add(this.tbMappingOptimize);
		this.tbSensitivity = this.makeNavigationButton(IconOptimizerToolbar.SENSITIVITY_SELECT,
				OptimizerToolBar.ACTION_SENSITIVIT_SELECT, "Select sensitivity", "Sensitivity");
		this.add(this.tbSensitivity);
	}

	private JButton makeNavigationButton(URL icon, String actionCommand, String toolTipText, String altText) {
		JButton button;

		button = new JButton();
		button.setEnabled(false);
		button.setActionCommand(actionCommand);
		button.setToolTipText(toolTipText);
		button.addActionListener(this);

		if (icon != null) {
			try {
				button.setIcon(new ImageIcon(icon));
			} catch (Exception e) {
				button.setText(altText);
			}
		} else {
			button.setText(altText);
		}

		return button;
	}

	@Override
	public void actionPerformed(ActionEvent e) {
		if (e.getActionCommand() == OptimizerToolBar.ACTION_WIZARD) {
			// FIXME
			this.controller.mnu_file_wizard();
		} else if (e.getActionCommand() == OptimizerToolBar.ACTION_REFRESH) {
			this.controller.mnu_display_refresh();
		} else if (e.getActionCommand() == OptimizerToolBar.ACTION_JOBMANAGER) {
			this.controller.mnu_display_jobmanager();
		} else if (e.getActionCommand() == OptimizerToolBar.ACTION_RUN) {
			this.controller.mnu_project_run();
		} else if (e.getActionCommand() == OptimizerToolBar.ACTION_FINISH) {
			this.controller.mnu_project_finish();
		} else if (e.getActionCommand() == OptimizerToolBar.ACTION_STOP) {
			this.controller.mnu_project_stop();
		} else if (e.getActionCommand() == OptimizerToolBar.ACTION_INIT_BUFFER) {
			this.controller.mnu_project_init_buffer();
		} else if (e.getActionCommand() == OptimizerToolBar.ACTION_CLEAR_BUFFER) {
			this.controller.mnu_project_clear_buffer();
		} else if (e.getActionCommand() == OptimizerToolBar.ACTION_EXCEL) {
			this.controller.mnu_project_create_excel();
		} else if (e.getActionCommand() == OptimizerToolBar.ACTION_SELECT) {
			this.controller.mnu_project_select();
		} else if (e.getActionCommand() == OptimizerToolBar.ACTION_ADD_PLOT) {
			this.controller.mnu_display_add_plot();
		} else if (e.getActionCommand() == OptimizerToolBar.ACTION_REMOVE_PLOT) {
			this.controller.mnu_display_remove_plot();
		} else if (e.getActionCommand() == OptimizerToolBar.ACTION_MAPPING_CREATE_ALL) {
			this.controller.mnu_mapping_create_all();
		} else if (e.getActionCommand() == OptimizerToolBar.ACTION_MAPPING_OPTIMIZE) {
			this.controller.mnu_mapping_optimize();
		} else if (e.getActionCommand() == OptimizerToolBar.ACTION_SENSITIVIT_SELECT) {
			this.controller.mnu_mapping_sensitivity();
		} else {
			System.out.println("Not implemented");
		}
	}

	@Override
	public void refresh() {
		boolean problemExist;

		// FIXME
		problemExist = this.controller.getProblem() != null;

		// FIXME dirty
		this.tbWizard.setEnabled(true);
		this.tbRefresh.setEnabled(true);
		this.tbJobManager.setEnabled(true);
		this.tbRun.setEnabled(this.controller.isRunEnabled());
		this.tbFinish.setEnabled(this.controller.isFinishEnabled());
		this.tbStop.setEnabled(this.controller.isStopEnabled());
		this.tbInitializeBuffer.setEnabled(problemExist);
		this.tbClearBuffer.setEnabled(problemExist);
		this.tbCreateExcel.setEnabled(problemExist);
		this.tbSelect.setEnabled(problemExist);
		this.tbAddPlot.setEnabled(problemExist);
		this.tbRemovePlot.setEnabled(problemExist && (this.controller.getProblem().listUserPlots().length > 0));
		new Thread() {
			@Override
			public void run() {
				final boolean create, optimize, sensitivity;

				create = OptimizerToolBar.this.controller.isCreateMappingEnabled();
				optimize = OptimizerToolBar.this.controller.isRunMappingEnabled();
				sensitivity = OptimizerToolBar.this.controller.isSensitivityInitializationEnabled();

				SwingUtilities.invokeLater(new Runnable() {

					@Override
					public void run() {
						OptimizerToolBar.this.tbMappingCreateAll.setEnabled(create);
						OptimizerToolBar.this.tbMappingOptimize.setEnabled(optimize);
						OptimizerToolBar.this.tbSensitivity.setEnabled(sensitivity);
					}
				});

			}
		}.start();

	}
}
