/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure;

import java.io.Serializable;
import java.rmi.Remote;
import java.rmi.RemoteException;

import at.lcm.bu21.magopt.structure.ReportParameter.Language;
import at.lcm.bu21.magopt.structure.ReportParameter.ReportProperty;

/**
 * Interface of report-parameter
 * 
 * @author Werner Koppelsttter
 */
public interface IReportParameter extends Remote, Serializable {

	/**
	 * Get selected language
	 * 
	 * @return Language
	 * @throws RemoteException
	 */
	public Language getLanguage() throws RemoteException;

	/**
	 * Set selected language
	 * 
	 * @param lang
	 *            Language
	 * @throws RemoteException
	 */
	public void setLanguage(Language lang) throws RemoteException;

	/**
	 * Get style path for report
	 * 
	 * @return Style path
	 * @throws RemoteException
	 */
	public String getStylePath() throws RemoteException;

	/**
	 * Get selected Style
	 * 
	 * @return Style
	 * @throws RemoteException
	 */
	public String getStyle() throws RemoteException;

	/**
	 * Set selected Style
	 * 
	 * @param style
	 *            Style
	 * @throws RemoteException
	 */
	public void setStyle(String style) throws RemoteException;

	/**
	 * Get list of valid report-properties
	 * 
	 * @return List of properties
	 * @throws RemoteException
	 */
	public ReportProperty[] getProperties() throws RemoteException;

	/**
	 * Get report-property for key
	 * 
	 * @param key
	 *            Key of property
	 * @return Style property
	 * @throws RemoteException
	 */
	public ReportProperty getProperty(String key) throws RemoteException;

	/**
	 * Set value of report-property
	 * 
	 * @param key
	 *            Key of property
	 * @param value
	 *            Value for property
	 * @throws RemoteException
	 */
	public void setProperty(String key, String value) throws RemoteException;

	/**
	 * Get client-implementation of interface
	 * 
	 * @return Client-implementation
	 * @throws RemoteException
	 */
	public IReportParameter getClientImpl() throws RemoteException;
}
