/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure.client;

import java.io.File;
import java.io.IOException;
import java.rmi.RemoteException;
import java.util.Map;
import java.util.concurrent.ExecutionException;

import at.lcm.bu21.general.utils.CloneException;
import at.lcm.bu21.magopt.structure.IProject;
import at.lcm.bu21.magopt.structure.IReportParameter;
import at.lcm.bu21.magopt.structure.event.IEventLog;
import magopt.utils.MopFile;

/**
 * Client adapter for project-interface
 * 
 * @author Werner Koppelsttter
 */
public class CProject extends CParamContainer implements IProject {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/** project class */
	private IProject param;

	/**
	 * Create client adapter for project interface
	 * 
	 * @param param
	 *            Project
	 */
	public CProject(IProject param) {
		super(param);
		this.param = param;
	}

	@Override
	public void close() throws RemoteException {
		this.param.close();
	}

	@Override
	public boolean isWriteProtected() throws RemoteException {
		return this.param.isWriteProtected();
	}

	@Override
	public void save() throws Exception {
		this.param.save();
	}

	@Override
	public void saveAs(String file) throws Exception {
		this.param.saveAs(file);
	}

	@Override
	public void saveAs(String file, boolean override) throws Exception {
		this.param.saveAs(file, override);
	}

	@Override
	public void saveAs(File file) throws Exception {
		this.param.saveAs(file);
	}

	@Override
	public void saveAs(File file, boolean override) throws Exception {
		this.param.saveAs(file, override);
	}

	@Override
	public String getDSComment() throws RemoteException {
		return this.param.getDSComment();
	}

	@Override
	public void setDSComment(String comment) throws RemoteException {
		this.param.setDSComment(comment);
	}

	@Override
	public IEventLog getEventLog() throws RemoteException {
		return this.param.getEventLog().getClientImpl();
	}

	@Override
	public String getFile() throws RemoteException {
		return this.param.getFile();
	}

	@Override
	public IReportParameter getReportParameter() throws RemoteException {
		return this.param.getReportParameter().getClientImpl();
	}

	@Override
	public double getGuiHandle() throws RemoteException {
		return this.param.getGuiHandle();
	}

	@Override
	public void setGuiHandle(double guiHandle) throws RemoteException {
		this.param.setGuiHandle(guiHandle);
	}

	@Override
	public String[] getAllDSComment() throws RemoteException {
		return this.param.getAllDSComment();
	}

	@Override
	public MopFile getMopFile() throws RemoteException {
		return this.param.getMopFile();
	}

	@Override
	public void check() throws RemoteException {
		this.param.check();
	}

	@Override
	public void duplicate() throws CloneException, IOException {
		this.param.duplicate();
	}

	@Override
	public void reduce() throws RemoteException {
		this.param.reduce();
	}

	@Override
	public int regenerate(Map<String, Object> args) throws RemoteException {
		return this.param.regenerate(args);
	}

	@Override
	public File getAllFilesDirectory() throws RemoteException {
		return this.param.getAllFilesDirectory();
	}

	@Override
	public File getFilesDirectory() throws RemoteException {
		return this.param.getFilesDirectory();
	}

	@Override
	public void resetAllFunctions() throws RemoteException {
		this.param.resetAllFunctions();
	}

	@Override
	public IProject extractIndex(int index, File file) throws Exception {
		return this.param.extractIndex(index, file);
	}

	@Override
	public void restartJep() throws InterruptedException, ExecutionException, RemoteException {
		this.param.restartJep();
	}

	@Override
	public CProject getClientImpl() {
		return this;
	}
}
