/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure.compare;

/**
 * Result of compare project
 * 
 * @author Werner Koppelsttter
 */
public class CompareResult {

	/** Identifier */
	private String identifier;

	/** Reason of different */
	private String reason;

	/** Different */
	private String difference;

	/**
	 * Create compare different
	 * 
	 * @param identifier
	 *            Identifier
	 * @param reason
	 *            Reason
	 * @param difference
	 *            Difference
	 */
	public CompareResult(String identifier, String reason, String difference) {
		this.identifier = identifier;
		this.reason = reason;
		this.difference = difference;
	}

	/**
	 * Get identifier of different
	 * 
	 * @return Identifier
	 */
	public String getIdentifier() {
		return this.identifier;
	}

	/**
	 * Get reason of different
	 * 
	 * @return Reason
	 */
	public String getReason() {
		return this.reason;
	}

	/**
	 * Get different
	 * 
	 * @return different
	 */
	public String getDifference() {
		return this.difference;
	}

	@Override
	public String toString() {
		StringBuffer buffer;

		buffer = new StringBuffer();

		buffer.append(this.reason);
		while (buffer.length() < 30) {
			buffer.append(" ");
		}
		buffer.append("| ");

		buffer.append(this.identifier);
		while (buffer.length() < 110) {
			buffer.append(" ");
		}
		buffer.append("| ");

		buffer.append(this.difference);

		return buffer.toString();
	}
}
