/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure.converter;

import at.lcm.bu21.general.utils.XMLNode;

/**
 * Convert to V_0_1.
 * 
 * - Reorder the position of the event-log <br>
 * - Remove old event-structure
 * 
 * @author Werner Koppelsttter
 */
class Converter_1 {

	/**
	 * Convert the given node
	 * 
	 * @param node
	 *            Data to convert
	 * @return Changed data node
	 */
	static XMLNode convert(XMLNode node) {

		Converter_1.updateEvent(node);

		return node;
	}

	/**
	 * Recursive update of the event-log
	 * 
	 * @param node
	 *            Node to update
	 */
	private static void updateEvent(XMLNode node) {
		XMLNode event = null;
		boolean removeBuffer = false;
		int i;

		// find event
		i = 0;
		while ((i < node.getNodeSize())
				&& (!node.getNode(i).getName().equals("Event"))) {
			event = node.getNode(i);
			i++;
		}
		// update event
		if (i < node.getNodeSize()) {
			// move Event on top
			event = node.rmNode(i);
			node.addNode(0, event);

			// update Event structure
			i = 0;
			while (i < event.getNodeSize()) {
				// remove EvList
				if (event.getNode(i).getName().equals("EvList")) {
					event.rmNode(i);
					removeBuffer = true;
				}
				// remove EvBuffer
				if (removeBuffer
						&& event.getNode(i).getName().equals("EvBuffer")) {
					event.getNode(i).clearNodes();
				}
				i++;
			}
		}
	}

}
