/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure.converter;

import at.lcm.bu21.general.utils.XMLNode;

/**
 * Convert to V_0_28.
 * 
 * - Bug in converter 0_28 (CheckSum of ParamFile)<br>
 * - Bug in ParamFormula
 * 
 * @author Werner Koppelsttter
 */
public class Converter_28 {

	/**
	 * Convert the given node
	 * 
	 * @param node
	 *            Data to convert
	 * @return Changed data node
	 */
	static XMLNode convert(XMLNode node) {

		// Convert File
		Converter_28.convertFile(node.getNode(0));
		// Convert Formula
		Converter_28.convertFormula(node.getNode(0));

		return node;
	}

	/**
	 * Convert ParamFile. Clear CheckSum of non constant.
	 * 
	 * @param node
	 *            Node to update
	 */
	private static void convertFile(XMLNode node) {

		if (node.getName().compareTo("ParamFile") == 0) {
			// if not constant
			if (node.getNode(0).getNode(0).getNode(4).getText()
					.compareTo("true") != 0) {
				// clear CheckSum
				node.getNode(2).clearNodes();
			}
		}

		// next node
		for (XMLNode n : node.getNodes()) {
			Converter_28.convertFile(n);
		}
	}

	/**
	 * Convert ParamFormula. Reduce exports to one.
	 * 
	 * @param node
	 *            Node to update
	 */
	private static void convertFormula(XMLNode node) {
		if (node.getName().compareTo("ParamFormula") == 0) {
			// Reduce to one export
			XMLNode exports = node.getNode(1).getNode(1);
			while (exports.getNodeSize() > 1) {
				exports.rmNode(1);
			}
		}

		// next node
		for (XMLNode n : node.getNodes()) {
			Converter_28.convertFormula(n);
		}
	}
}
