/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure.rmi;

import java.io.File;
import java.rmi.RemoteException;
import java.rmi.server.UnicastRemoteObject;

import at.lcm.bu21.magopt.structure.Component;
import at.lcm.bu21.magopt.structure.IComponent;
import at.lcm.bu21.magopt.structure.IParamContainer;
import at.lcm.bu21.magopt.structure.client.CComponent;

/**
 * RMI adapter for component
 * 
 * @author Werner Koppelsttter
 */
public class RComponent extends UnicastRemoteObject implements IComponent {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/** Component class */
	private Component component;

	/**
	 * Create rmi adapter for Component
	 * 
	 * @param component
	 *            Component
	 * @throws RemoteException
	 */
	public RComponent(Component component) throws RemoteException {
		this.component = component;
	}

	// @Override
	// public File getPath() throws RemoteException {
	// return this.component.getPath();
	// }

	@Override
	public void refresh() throws RemoteException {
		this.component.refresh();
	}

	// FIXME

	@Override
	public CComponent getClientImpl() {
		return new CComponent(this);
	}

	@Override
	public File getFolder() throws RemoteException {
		return this.component.getFolder();
	}

	@Override
	public File getHelpFile() throws RemoteException {
		return this.component.getHelpFile();
	}

	@Override
	public File getImage() throws RemoteException {
		return this.component.getImage();
	}

	@Override
	public File[] listLinkedFiles() throws RemoteException {
		return this.component.listLinkedFiles();
	}

	@Override
	public String getRelLinkedFile(File file) throws RemoteException {
		return this.component.getRelLinkedFile(file);
	}

	@Override
	public IParamContainer getContainer() throws RemoteException {
		return this.component.getContainer();
	}
}
