/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package magopt.gui;

import java.rmi.RemoteException;

import javax.swing.JOptionPane;

import magopt.gui.helpers.JProgressDialog;
import at.lcm.bu21.magopt.structure.IParameter;
import at.lcm.bu21.magopt.structure.Parameter;

/**
 * Runs Delete Process in a non-EDT Thread.
 * 
 * @author Aigner Markus
 * 
 */
public class DeleteThread extends BaseThread {

	protected DeleteThread(MagOptGui gui) {
		super(gui);

		IParameter selected = this.mGui.mProjectTree.getSelectedParameter();
		int response;
		try {
			response = JOptionPane.showConfirmDialog(this.mGui, "Delete \""
					+ selected.getName() + "\".\nContinue ?", "Warning",
					JOptionPane.YES_NO_OPTION, JOptionPane.WARNING_MESSAGE);
			if (response == JOptionPane.YES_OPTION) {
				this.mPD = new JProgressDialog(this.mGui, "Delete Parameter",
						"Deleting ...");
			} else {
				this.cancel(true);
			}
		} catch (RemoteException e) {
			this.cancel(true);
			e.printStackTrace();
		}
	}

	@Override
	protected Void doInBackground() throws Exception {
		Parameter selected = (Parameter) this.mGui.mProjectTree
				.getSelectedParameter();
		this.mGui.mProjectTree.selectNode(selected.getParent().getIdentifier());
		selected.removeParam();
		return null;
	}

	@Override
	protected void done() {
		if (this.isCancelled() == true) {
			return;
		}
		this.mGui.updateTreeComponent();
		this.mGui.updateViewComponent();
		this.mGui.updateEventComponent();
		this.mGui.updateBars();
		this.mPD.setVisible(false);
	}
}
