/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package magopt.gui;

import java.awt.datatransfer.DataFlavor;
import java.awt.datatransfer.Transferable;
import java.awt.datatransfer.UnsupportedFlavorException;
import java.io.IOException;

import at.lcm.bu21.magopt.structure.Parameter;

/**
 * Manages Clipboard Actions using the System Clipboard.
 * 
 * @author Aigner Markus
 * 
 */
public class ParameterSelection implements Transferable {
	static protected DataFlavor mParamFlavor;
	private ClipboardData mClipboardData;
	private DataFlavor[] mSupportedFlavors = new DataFlavor[1];

	protected ParameterSelection(Parameter param, boolean cut) {
		this.mClipboardData = new ClipboardData(param, cut);
		mParamFlavor = new DataFlavor(this.mClipboardData.getClass(),
				"ClipboardData");
		this.mSupportedFlavors[0] = mParamFlavor;
	}

	@Override
	public synchronized Object getTransferData(DataFlavor flavor)
			throws UnsupportedFlavorException, IOException {
		if (flavor.equals(mParamFlavor) == true) {
			return (this.mClipboardData);
		} else {
			throw new UnsupportedFlavorException(flavor);
		}
	}

	@Override
	public synchronized DataFlavor[] getTransferDataFlavors() {
		return (this.mSupportedFlavors);
	}

	@Override
	public boolean isDataFlavorSupported(DataFlavor flavor) {
		if (flavor.equals(mParamFlavor) == true) {
			return (true);
		} else {
			return false;
		}
	}
}
