/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package magopt.gui.component.browser;

import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.Insets;
import java.awt.LayoutManager2;

/**
 * 
 *
 * @author Werner Koppelsttter
 */
public class VerticalLayout implements LayoutManager2 {

	/** Gap between components */
	private int gap = 0;

	/**
	 * Layout for vertical alignment
	 * 
	 * @param gap
	 */
	public VerticalLayout(int gap) {
		this.gap = gap;
	}

	@Override
	public void addLayoutComponent(String name, Component comp) {
	}

	@Override
	public void removeLayoutComponent(Component comp) {
	}

	@Override
	public Dimension preferredLayoutSize(Container parent) {
		Dimension dim = new Dimension(0, 0);
		Dimension d;
		Insets insets;
		int count;

		for (Component comp : parent.getComponents()) {
			d = comp.getPreferredSize();
			dim.width = d.width > dim.width ? d.width : dim.width;
			dim.height += d.height;
		}

		insets = parent.getInsets();
		dim.width += insets.left + insets.right;
		dim.height += insets.top + insets.bottom;

		count = parent.getComponentCount();
		if (count > 1) {
			dim.height += (parent.getComponentCount() - 1) * this.gap;
		}

		return dim;
	}

	@Override
	public Dimension minimumLayoutSize(Container parent) {
		Dimension dim = new Dimension(0, 0);
		Dimension d;
		Insets insets;
		int count;

		for (Component comp : parent.getComponents()) {
			d = comp.getMinimumSize();
			dim.width = d.width > dim.width ? d.width : dim.width;
			dim.height += d.height;
		}

		insets = parent.getInsets();
		dim.width += insets.left + insets.right;
		dim.height += insets.top + insets.bottom;

		count = parent.getComponentCount();
		if (count > 1) {
			dim.height += (parent.getComponentCount() - 1) * this.gap;
		}

		return dim;
	}

	@Override
	public void layoutContainer(Container parent) {
		Insets insets = parent.getInsets();
		int top = insets.top;
//		int center = (parent.getWidth() - insets.left - insets.right) / 2;
		Dimension dim;

		for (Component comp : parent.getComponents()) {
			dim = comp.getPreferredSize();
//			comp.setBounds(insets.left + (center - (dim.width / 2)), top, dim.width, dim.height);
			comp.setBounds(insets.left, top, dim.width, dim.height);
			top += dim.height + this.gap;
		}

	}

	@Override
	public void addLayoutComponent(Component comp, Object constraints) {
	}

	@Override
	public Dimension maximumLayoutSize(Container parent) {
		Dimension dim = new Dimension(0, 0);
		Dimension d;
		Insets insets;
		int count;

		for (Component comp : parent.getComponents()) {
			d = comp.getMaximumSize();
			dim.width = d.width > dim.width ? d.width : dim.width;
			dim.height += d.height;
		}

		insets = parent.getInsets();
		dim.width += insets.left + insets.right;
		dim.height += insets.top + insets.bottom;

		count = parent.getComponentCount();
		if (count > 1) {
			dim.height += (parent.getComponentCount() - 1) * this.gap;
		}

		return dim;
	}

	@Override
	public float getLayoutAlignmentX(Container parent) {
		return 0f;
	}

	@Override
	public float getLayoutAlignmentY(Container parent) {
		return 0f;
	}

	@Override
	public void invalidateLayout(Container parent) {

	}
}
