/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9749 $
 * $Date: 2020-04-10 16:00:50 +0200 (Fri, 10 Apr 2020) $
 */
package magopt.gui.view.details;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import java.lang.reflect.InvocationTargetException;
import java.rmi.RemoteException;

import javax.swing.GroupLayout;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.SwingUtilities;

import at.lcm.bu21.general.dtypes.TBoolean;
import at.lcm.bu21.general.dtypes.TData;
import at.lcm.bu21.general.dtypes.TNull;
import at.lcm.bu21.general.dtypes.TNumeric;
import at.lcm.bu21.general.dtypes.TString;
import at.lcm.bu21.magopt.structure.IParamField;
import at.lcm.bu21.magopt.structure.ParamField;
import magopt.gui.helpers.DataEditor;
import magopt.gui.view.ParamBaseNoScroll;

/**
 * Displays ParamField specific Data:<br>
 * - Data<br>
 * - Unit<br>
 * - Tex String<br>
 * - Type<br>
 * - Constant Flag Status
 * 
 * @author Aigner Markus
 * @author Werner Koppelsttter
 * 
 */
public class ParamFieldView extends ParamBaseNoScroll implements ActionListener, FocusListener {
	private static final long serialVersionUID = 1L;

	private JTextField mName;
	private JTextField mDescription;
	private JTextField mComment;

	protected JTextField mData;
	protected JTextField mUnit;
	protected JTextField mTexString;
	protected JTextField mType;
	protected JCheckBox mConstant;

	protected JButton bEdit;
	protected JButton bShow;

	protected boolean show;

	protected IParamField mPField;

	private int ret;

	public ParamFieldView() {
		JPanel mainPane = new JPanel();
		this.setLayout(new BorderLayout());
		this.add(mainPane);

		GroupLayout layout = new GroupLayout(mainPane);
		mainPane.setLayout(layout);
		layout.setAutoCreateGaps(true);
		layout.setAutoCreateContainerGaps(true);

		/* name */
		JLabel lName = new JLabel("Name:");
		this.mName = new JTextField();
		this.mName.addActionListener(this);
		this.mName.addFocusListener(this);

		/* description */
		JLabel lDesc = new JLabel("Description:");
		this.mDescription = new JTextField();
		this.mDescription.addActionListener(this);
		this.mDescription.addFocusListener(this);

		/* comment */
		JLabel lComment = new JLabel("Comment:");
		this.mComment = new JTextField();
		this.mComment.addActionListener(this);
		this.mComment.addFocusListener(this);

		/* data */
		JLabel lData = new JLabel("Data:");
		this.mData = new JTextField();
		this.mData.addActionListener(this);
		this.mData.addFocusListener(this);

		/* edit */
		this.bEdit = new JButton("Edit");
		this.bEdit.addActionListener(this);
		// this.bEdit.addFocusListener(this);

		/* show */
		this.bShow = new JButton("Show");
		this.bShow.addActionListener(this);
		// this.bShow.addFocusListener(this);

		/* unit */
		JLabel lUnit = new JLabel("Unit:");
		this.mUnit = new JTextField();
		this.mUnit.addActionListener(this);
		this.mUnit.addFocusListener(this);

		/* tex string */
		JLabel lTexString = new JLabel("Tex String:");
		this.mTexString = new JTextField();
		this.mTexString.addActionListener(this);
		this.mTexString.addFocusListener(this);

		/* type */
		JLabel lType = new JLabel("Type:");
		this.mType = new JTextField();
		this.mType.addActionListener(this);
		this.mType.addFocusListener(this);

		/* constant flag */
		JLabel lConstant = new JLabel();
		this.mConstant = new JCheckBox("Constant");
		this.mConstant.addActionListener(this);

		/* config group layout */
		layout.setHorizontalGroup(layout.createSequentialGroup()
				.addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING).addComponent(lName)
						.addComponent(lDesc).addComponent(lComment).addComponent(lData).addComponent(lUnit)
						.addComponent(lTexString).addComponent(lType).addComponent(lConstant))
				.addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING).addComponent(this.mName)
						.addComponent(this.mDescription).addComponent(this.mComment).addComponent(this.mData)
						.addGroup(layout.createSequentialGroup().addComponent(this.bEdit).addComponent(this.bShow))
						.addComponent(this.mUnit).addComponent(this.mTexString).addComponent(this.mType)
						.addComponent(this.mConstant))
				.addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING).addComponent(this.bShow)));
		layout.setVerticalGroup(layout.createSequentialGroup()
				.addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE).addComponent(lName)
						.addComponent(this.mName))
				.addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE).addComponent(lDesc)
						.addComponent(this.mDescription))
				.addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE).addComponent(lComment)
						.addComponent(this.mComment))
				.addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE).addComponent(lData)
						.addComponent(this.mData))
				.addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE).addComponent(this.bEdit)
						.addComponent(this.bShow))
				.addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE).addComponent(lUnit)
						.addComponent(this.mUnit))
				.addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE).addComponent(lTexString)
						.addComponent(this.mTexString))
				.addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE).addComponent(lType)
						.addComponent(this.mType))
				.addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE).addComponent(lConstant)
						.addComponent(this.mConstant)));
	}

	@Override
	public void focusGained(FocusEvent e) {
		// reload value
		if (e.getSource() == this.mData) {
			try {
				this.mData.setText(this.mPField.getData().toString());
			} catch (RemoteException e1) {
				e1.printStackTrace();
			}
		}
	}

	@Override
	public void focusLost(FocusEvent e) {
		this.doWork(e.getSource());
	}

	@Override
	public void actionPerformed(ActionEvent e) {
		this.doWork(e.getSource());
	}

	private void doWork(Object obj) {
		new Thread() {
			@Override
			public void run() {
				try {
					if (obj == ParamFieldView.this.mName) {
						ParamFieldView.this.mPField.setName(ParamFieldView.this.mName.getText());
					} else if (obj == ParamFieldView.this.mDescription) {
						ParamFieldView.this.mPField.setDescription(ParamFieldView.this.mDescription.getText());
					} else if (obj == ParamFieldView.this.mComment) {
						ParamFieldView.this.mPField.setComment(ParamFieldView.this.mComment.getText());
					} else if (obj == ParamFieldView.this.mData) {
						JTextField field = (JTextField) obj;
						if (field.isEditable()) {
							String str = field.getText();
							ParamFieldView.this.mPField.setData(TData.createData(str));
							ParamFieldView.this.updateDataEditable();
						}
					} else if (obj == ParamFieldView.this.mUnit) {
						synchronized (ParamFieldView.this) {
							if ((ParamFieldView.this.mUnit.getText() != null)
									&& (!ParamFieldView.this.mUnit.getText().isEmpty())
									&& (ParamFieldView.this.mPField.getUnit() != null)
									&& (!ParamFieldView.this.mPField.getUnit().isEmpty())
									&& !ParamFieldView.this.mPField.getUnit()
											.equals(ParamFieldView.this.mUnit.getText())) {

								SwingUtilities.invokeAndWait(new Runnable() {
									@Override
									public void run() {
										ParamFieldView.this.ret = JOptionPane.showConfirmDialog(ParamFieldView.this,
												"Do you want to convert value to new unit?\n" + "Please confirm!",
												"Data conversion confirmation", JOptionPane.YES_NO_OPTION,
												JOptionPane.WARNING_MESSAGE, null);
									}
								});

								ParamFieldView.this.mPField.setUnit(ParamFieldView.this.mUnit.getText(),
										ParamFieldView.this.ret != JOptionPane.NO_OPTION);
							} else {
								ParamFieldView.this.mPField.setUnit(ParamFieldView.this.mUnit.getText());
							}
						}

					} else if (obj == ParamFieldView.this.mTexString) {
						ParamFieldView.this.mPField.setTexString(ParamFieldView.this.mTexString.getText());
					} else if (obj == ParamFieldView.this.mType) {
						ParamFieldView.this.mPField.setType(ParamFieldView.this.mType.getText());
					} else if (obj == ParamFieldView.this.mConstant) {
						ParamFieldView.this.mPField.setConstant(ParamFieldView.this.mConstant.isSelected());
					} else if (obj == ParamFieldView.this.bEdit) {
						// FIXME RMI
						new DataEditor((ParamField) ParamFieldView.this.mPField);
					} else if (obj == ParamFieldView.this.bShow) {
						ParamFieldView.this.show = true;
						ParamFieldView.this.bShow.setEnabled(!ParamFieldView.this.show);
					}
				} catch (RemoteException ex) {
					ex.printStackTrace();
				} catch (Exception ex) {
					try {
						ParamFieldView.this.mPField.error(ex.getMessage(), ex.getStackTrace());
					} catch (RemoteException e) {
						e.printStackTrace();
					}
				}

				try {
					SwingUtilities.invokeAndWait(new Runnable() {

						@Override
						public void run() {
							ParamFieldView.this.update();
							ParamFieldView.this.fireParamChanged();
						}
					});
				} catch (InvocationTargetException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				} catch (InterruptedException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
			}
		}.start();
	}

	public void setField(IParamField pField) {
		this.mPField = pField;
		try {
			this.show = !this.mPField.getUncertain();
			this.bShow.setEnabled(!this.show);
		} catch (RemoteException e) {
			e.printStackTrace();
		}
		this.update();
	}

	@Override
	protected void update() {
		try {
			this.mName.setText(this.mPField.getName());
			this.mDescription.setText(this.mPField.getDescription());
			this.mComment.setText(this.mPField.getComment());
			if (this.show) {
				this.mData.setText(this.mPField.getData().toString());
				this.updateDataEditable();
			} else {
				this.mData.setText("[Uncertain]");
				this.mData.setEditable(false);
			}
			this.mUnit.setText(this.mPField.getUnit());
			this.mTexString.setText(this.mPField.getTexString());
			this.mType.setText(this.mPField.getType());
			this.mConstant.setSelected(this.mPField.getConstant());
		} catch (RemoteException e) {
			e.printStackTrace();
		}
	}

	private void updateDataEditable() throws RemoteException {
		TData data = this.mPField.getData();
		if (this.mPField.getReadOnly()) {
			this.mData.setEditable(false);
		} else {
			if (data.getClass().equals(TNumeric.class)) {
				this.mData.setEditable(data.toString().equals(((TNumeric) data).toFullString()));
			} else if (data.getClass().equals(TString.class)) {
				this.mData.setEditable(data.toString().equals("'" + ((TString) data).getString() + "'"));
			} else if (data.getClass().equals(TBoolean.class)) {
				this.mData.setEditable(true);
			} else if (data.getClass().equals(TNull.class)) {
				this.mData.setEditable(true);
			} else {
				this.mData.setEditable(false);
			}
		}
	}
}
