/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package magopt.gui.view.report;

import java.rmi.RemoteException;

import javax.swing.JTable;
import javax.swing.event.TableModelEvent;
import javax.swing.event.TableModelListener;
import javax.swing.table.AbstractTableModel;

import at.lcm.bu21.magopt.structure.IReportParameter;
import at.lcm.bu21.magopt.structure.ReportParameter.ReportProperty;

/**
 * Table-model for report-properties
 * 
 * @author Werner Koppelsttter
 */
public class ReportPropertyModel extends AbstractTableModel {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/** Report-parameters */
	protected IReportParameter report = null;

	/**
	 * Set project for display report-properties
	 * 
	 * @param report
	 *            Report-parameters
	 */
	public void setReport(IReportParameter report) {
		this.report = report;

		// refresh table of model
		for (TableModelListener listener : this
				.getListeners(TableModelListener.class)) {
			if ((listener instanceof JTable)
					&& this.equals(((JTable) listener).getModel())) {
				listener.tableChanged(new TableModelEvent(this));
			}
		}
	}

	@Override
	public int getColumnCount() {
		return ReportPropertyColumn.values().length;
	}

	@Override
	public int getRowCount() {
		int len = 0;
		if (this.report != null) {
			try {
				len = this.report.getProperties().length;
			} catch (RemoteException e) {
				e.printStackTrace();
			}
		}

		return len;
	}

	@Override
	public Object getValueAt(int row, int column) {
		Object obj = null;
		ReportProperty[] list;

		if (this.report != null) {
			try {
				list = this.report.getProperties();
				if (column == ReportPropertyColumn.KEY.getValue()) {
					obj = list[row].getKey();
				} else if (column == ReportPropertyColumn.VALUE.getValue()) {
					obj = list[row].getValue();
				} else {
					obj = list[row];
				}
			} catch (RemoteException e) {
				e.printStackTrace();
			}
		}

		return obj;
	}

	@Override
	public String getColumnName(int column) {
		for (ReportPropertyColumn e : ReportPropertyColumn.values()) {
			if (column == e.getValue()) {
				return e.getName();
			}
		}
		return null;
	}

	@Override
	public Class<?> getColumnClass(int column) {
		Class<?> cl = String.class;

		return cl;
	}

	@Override
	public boolean isCellEditable(int row, int column) {
		boolean edit = false;

		// if (column == ReportParamColumn.KEY.getValue()) {
		// edit = true;
		// }
		if (column == ReportPropertyColumn.VALUE.getValue()) {
			edit = true;
		}

		return edit;
	}

	@Override
	public void setValueAt(Object value, int row, int col) {
		if (this.report != null) {
			if (col == ReportPropertyColumn.VALUE.getValue()) {
				try {
					this.report.getProperties()[row].setValue((String) value);
				} catch (RemoteException e) {
					e.printStackTrace();
				}
				this.fireTableDataChanged();
			}
		}
	}

}
