/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package magopt.utils;

import java.io.File;
import java.net.URISyntaxException;

import at.lcm.bu21.general.utils.FileUtils;
import at.lcm.bu21.magopt.utils.MagOptConfig;
import at.lcm.bu21.magopt.utils.ReadZip;

/**
 * Create movie
 * 
 * @author Werner Koppelsttter
 */
public class CreateMovie {

	private static File getZip() {
		File zipFile = null;

		// locate zip-file
		try {
			zipFile = new File(new File(CreateMovie.class.getProtectionDomain().getCodeSource().getLocation().toURI())
					.getParentFile(), "im.zip");
		} catch (URISyntaxException e) {
		}

		if ((zipFile == null) || !zipFile.exists()) {
			zipFile = FileUtils.getFile(MagOptConfig.getHome(), "External", "ImageMagick", "im.zip");
		}

		return zipFile;
	}

	/**
	 * Create movie from ps
	 * 
	 * @param directory
	 *            Directory with source-files
	 * @return Path of movie-file
	 */
	public static String createMoviefromPS(String directory) {
		File file;
		file = CreateMovie.createMoviefromPS(new File(directory));
		if (file != null) {
			return file.getPath();
		} else {
			return null;
		}
	}

	/**
	 * Create movie from ps
	 * 
	 * @param directory
	 *            Directory with source-files
	 * @return Path of movie-file
	 */
	public static File createMoviefromPS(File directory) {
		Execute exec;
		ReadZip zip;
		File movie = new File(directory, "movie.mpeg");

		try {
			// extract zipFile
			zip = new ReadZip(CreateMovie.getZip());
			zip.unzip(directory);

			// convert from ps to jpg
			exec = new Execute(".\\im\\convert.exe", "-quality", "100", "*.PS", "out-%04d.jpg");
			exec.setDirectory(directory);
			exec.setDiscardStreams(true);
			exec.start();
			exec.exitValue();

			// create movie
			exec = new Execute(".\\im\\convert.exe", "-quality", "100", "-delay", "10", "*.jpg", movie.getName());
			exec.setDirectory(directory);
			exec.setDiscardStreams(true);
			exec.start();
			exec.exitValue();

			FileUtils.delete(new File(directory, "im"));

		} catch (Exception ex) {
			System.out.println(ex.getMessage());
			ex.printStackTrace();
		}

		if (movie.exists()) {
			return movie;
		} else {
			return null;
		}
	}

	/**
	 * Convert ps-image to jpg-image
	 * 
	 * @param ps
	 *            Postscript file
	 * @return jpg file
	 */
	public static File convertPS2JPG(File ps) {
		Execute exec;
		ReadZip zip;
		File jpg = null;
		File directory;
		String psName, jpgName;

		directory = ps.getParentFile();
		psName = ps.getName();
		if (psName.toLowerCase().endsWith(".ps")) {
			jpgName = psName.substring(0, psName.length() - 3) + ".jpg";
			jpg = new File(directory, jpgName);
			try {
				// extract zipFile
				zip = new ReadZip(CreateMovie.getZip());
				zip.unzip(directory);

				// convert from ps to jpg
				exec = new Execute(".\\im\\convert.exe", "-quality", "100", psName, jpgName);
				exec.setDirectory(directory);
				exec.setDiscardStreams(true);
				exec.start();
				exec.exitValue();

				FileUtils.delete(new File(directory, "im"));
				FileUtils.delete(new File(directory, "mp"));

			} catch (Exception ex) {
				System.out.println(ex.getMessage());
				ex.printStackTrace();
			}
		}

		if ((jpg != null) && jpg.exists()) {
			return jpg;
		} else {
			return null;
		}
	}

}
