/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 247 $
 * $Date: 2020-03-19 10:13:52 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.optim.core.mapping.utils.comparators;

import java.util.Comparator;

import at.lcm.bu21.optim.core.mapping.utils.dstructures.TMappingConstants;
import at.lcm.bu21.optim.core.mapping.utils.dstructures.TMappingTask;

public class MappingTaskEstimatedExecutionTimeComparator implements Comparator<TMappingTask> {

	@Override
	public int compare(TMappingTask arg0, TMappingTask arg1) {
		if (arg0.getParameters().get(TMappingTask.TParameter.MOD_TYPE.getValue()).toUpperCase()
				.equals(TMappingConstants.TRegressionModelType.ANN.getValue())
				&& arg1.getParameters().get(TMappingTask.TParameter.MOD_TYPE.getValue()).toUpperCase()
						.equals(TMappingConstants.TRegressionModelType.ANN.getValue())) {
			double h0 = Double.parseDouble(arg0.getParameters().get(TMappingTask.TParameter.HIDDEN_UNITS.getValue()));
			double h1 = Double.parseDouble(arg1.getParameters().get(TMappingTask.TParameter.HIDDEN_UNITS.getValue()));
			double l0 = Double.parseDouble(arg0.getParameters().get(TMappingTask.TParameter.LEARN_RATE.getValue()));
			double l1 = Double.parseDouble(arg1.getParameters().get(TMappingTask.TParameter.LEARN_RATE.getValue()));
			double m0 = Double.parseDouble(arg0.getParameters().get(TMappingTask.TParameter.MOMENTUM.getValue()));
			double m1 = Double.parseDouble(arg1.getParameters().get(TMappingTask.TParameter.MOMENTUM.getValue()));
			if (h0 < h1) {
				return 1;
			}
			if (h0 > h1) {
				return -1;
			}
			if (l0 > l1) {
				return 1;
			}
			if (l0 < l1) {
				return -1;
			}
			if (m0 > m1) {
				return 1;
			}
			if (m0 < m1) {
				return -1;
			}
			return 0;
		} else {
			return 0;
		}
	}

}
