/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 247 $
 * $Date: 2020-03-19 10:13:52 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.optim.gui.setting;

import java.awt.BorderLayout;

import javax.swing.GroupLayout;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.LayoutStyle;

import at.lcm.bu21.optim.algorithm.JPanelSolver;
import at.lcm.bu21.optim.algorithm.Solver;

/**
 * Panel to change solver-settings
 * 
 * @author Gnther Weidenholzer
 * @author Werner Koppelsttter
 */
public class SolverSettings extends SettingsPanel {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/** Problem to display */
	private Solver solver = null;

	/** Refresh panel */
	private PanelRefresh refresh = null;

	/** Panel enabled */
	private boolean enable = true;

	/** Solver panel */
	private JPanelSolver solverPanel;

	/** Text-area for description */
	private JTextArea txtDescription;

	/** Panel for solver settings */
	private JPanel panelSolver;

	/**
	 * Validate solver
	 * 
	 * @param sol
	 *            Solver
	 * 
	 * @return Message if not valid
	 */
	public static String validate(Solver sol) {
		String message = null;

		return message;
	}

	/**
	 * Create panel. Used by WindowsBuilder
	 */
	private SolverSettings() {
		this.initComponents();
	}

	/**
	 * Creates new form solver-settings
	 * 
	 * @param solver
	 *            Solver to set settings
	 * @param refresh
	 *            Refresh panel
	 */
	public SolverSettings(Solver solver, PanelRefresh refresh) {
		this(solver);
		this.refresh = refresh;
	}

	/**
	 * Creates new form solver-settings
	 * 
	 * @param solver
	 *            Solver to set settings
	 */
	public SolverSettings(Solver solver) {
		this();
		this.solver = solver;

		if (this.solver != null) {
			this.txtDescription.setText(this.solver.toString());

			this.solverPanel = this.solver.getPanel();
			this.panelSolver.add(this.solverPanel);

			this.refreshEnabled();
		}
	}

	/**
	 * Refresh panel
	 */
	protected void refresh() {
		if (this.refresh != null) {
			this.refresh.refresh();
		}
	}

	@Override
	public String validateContents() {
		return SolverSettings.validate(this.getSolver());
	}

	/**
	 * Are settings enabled
	 * 
	 * @return Setting enable
	 */
	public boolean isSettingEnabled() {
		return this.enable;
	}

	/**
	 * Set settings enabled
	 * 
	 * @param enable
	 *            Settings enable
	 */
	public void setSettingEnabled(boolean enable) {
		this.enable = enable;
		this.solverPanel.setSettingEnabled(enable);
		this.refreshEnabled();
	}

	/**
	 * Refresh enable state of components
	 */
	private void refreshEnabled() {
		this.solverPanel.refreshEnabled();
	}

	/**
	 * Get solver of panel
	 * 
	 * @return Solver
	 */
	public Solver getSolver() {
		return this.solver;
	}

	/**
	 * Initialize components
	 */
	private void initComponents() {
		JScrollPane jScrollDescription;
		JLabel labDescription, labSolver;

		// description
		labDescription = new JLabel("Solver description:");

		this.txtDescription = new JTextArea();
		this.txtDescription.setColumns(20);
		this.txtDescription.setRows(5);
		this.txtDescription.setEnabled(false);
		jScrollDescription = new JScrollPane();
		jScrollDescription.setViewportView(this.txtDescription);

		// options
		labSolver = new JLabel("Options:");

		this.panelSolver = new JPanel();
		this.panelSolver.setLayout(new BorderLayout());

		// layout
		GroupLayout layout = new GroupLayout(this);
		this.setLayout(layout);
		layout.setHorizontalGroup(layout.createSequentialGroup().addContainerGap()
				.addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING).addComponent(labDescription)
						.addComponent(jScrollDescription, GroupLayout.DEFAULT_SIZE, 612, Short.MAX_VALUE)
						.addComponent(labSolver).addComponent(this.panelSolver, GroupLayout.DEFAULT_SIZE,
								GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
				.addContainerGap());
		layout.setVerticalGroup(layout.createSequentialGroup().addContainerGap().addComponent(labDescription)
				.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
				.addComponent(jScrollDescription, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE,
						GroupLayout.PREFERRED_SIZE)
				.addGap(16, 16, 16).addComponent(labSolver).addPreferredGap(LayoutStyle.ComponentPlacement.UNRELATED)
				.addComponent(this.panelSolver, GroupLayout.DEFAULT_SIZE, GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
				.addContainerGap());
	}
}
