#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 9883 $
$LastChangedDate:: 2020-06-19 12:39:29 +0200#$

This file is part of SyMSpace.

Copyright (c) 2020, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""
from symspace.wrapper.symoptwrapper import SymArchive, SymProblem


def printNumProjectIndividuals(prj_file: str):
    '''use all existing archive names of this project'''
    archive_names = SymArchive.listArchives(prj_file)

    for index, a_name in enumerate(archive_names):
        '''loop over archive names'''
        archive = SymArchive.load(prj_file, a_name)
        memory = archive.getMemory()
        n_ind = memory.getNumIndividuals()
        print('{} - Number of individuals: {}'.format(a_name, n_ind))

        '''use all existing problem names of this archive'''
        problem_names = archive.listProblems()

        for p_name in problem_names:
            '''loop over problem names'''
            problem = archive.readProblem(p_name)
            n_val_ind = len(memory.getValidIndividuals(problem))
            print('{} {} - Number of valid individuals: {}'.format(a_name, p_name, n_val_ind))


def printProblemNumIndividuals(problem: SymProblem):
    p_name = problem.getName()
    archive = problem.getArchive()
    a_name = archive.getName()
    memory = archive.getMemory()
    n_ind = memory.getNumIndividuals()
    n_ind_vd = len(memory.getValidIndividuals(problem))
    print('{} - Number of individuals: {}'.format(a_name, n_ind))
    print('{} {} - Number of valid individuals: {}'.format(a_name, p_name, n_ind_vd))


if __name__ == '__main__':

    if 'Problem' in locals():
        '''Use from Optimizer Python Console in DebugMode (config.local -> OptimizerDebug=true)'''
        printProblemNumIndividuals(problem=locals()['Problem'])
    elif '__project__' in locals() or 'CurProject' in locals():
        '''Use from SyMSpace Console'''
        if '__project__' in locals():
            project = locals()['__project__']
        else:
            project = locals()['CurProject']
        prj_file = project.javaObj.getFile()
        printNumProjectIndividuals(prj_file)
    else:
        print('Unable to run script: Input parameters missing!\n')
        print('For usage in SyMSpace Center:')
        print('\tStart as Macro: SyMSpace Menu: Edit -> Run Macro (Ctrl+M)')
        print('\tOr assign "CurProject": SyMSpace Menu: '
              'Debug -> Python -> Assign Project Handle in Python Console (Ctrl+P)')

        print('For usage in SyMSpace Optimizer:')
        print('\tset in config.local -> OptimizerDebug=true')
        print('\tOptimizer Menu: Debug -> Assign problem to python')
