#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision$
$LastChangedDate::                           $

This file is part of SyMSpace.

Copyright (c) 2018, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""

import sys
import os

symspace_home = os.getenv('MagOpt_Home')
cs_home = os.getenv('ComponentSpace')
if symspace_home is not None:
    csymspace_exe = os.path.join(symspace_home, 'CSyMSpace.exe')
    test_reports_dir = os.getenv('TEST_REPORTS', os.path.join(symspace_home, 'TEST_REPORTS'))
    if cs_home is None:
        cs_test_reports_dir = test_reports_dir
    else:
        cs_test_reports_dir = os.getenv('TEST_REPORTS', os.path.join(cs_home, 'TEST_REPORTS'))
else:
    csymspace_exe = None
    test_reports_dir = None
    cs_test_reports_dir = None
python_dir = os.path.dirname(os.path.dirname(os.__file__))
python_exe = os.path.join(python_dir, 'python.exe')


class CMDParser:

    @staticmethod
    def jepSysArgs():
        """
        Get sys args in the correct form.

        Bug in jep returns tuple instead of list,
        this causes problems when using functions of the optparse package.

        Returns
        -------
        args : list
        """
        args = list(sys.argv[1:])
        return args

    @staticmethod
    def jepArgPath(path: str) -> str:
        """
        Correct the path passed as commandline argument to a jep console

        SyMSpace Bug #612
        https://redmine.lcm.at/redmine/issues/612

        e.g:

        CSyMSpace.exe myscript.py 'C:\opt'

        path gets 'C\:\opt' due to a jep bug

        Parameters
        ----------
        path : str
            input path

        Returns
        -------
        new_path : str
            corrected path
        """
        path_list = list(path)
        if path_list[1] == '\\':
            path_list[1] = ''
        new_path = ''.join(path_list)
        return os.path.abspath(new_path)
