import os
import glob
import unittest
import tempfile
from symspace.testing.symtestrunner import SymXmlTestRunner
from symspace.osutils.processutils import getInterpreter
from symspace.osutils.pathutils import symspace_home

'''only for local tests -> set to False before svn commit'''
show_html_report = False


class TestSymXmlTestRunner(unittest.TestCase):

    def test_discover(self):
        path = os.path.join(symspace_home, 'System', 'Python', 'tests')
        expected_file = os.path.join(path, 'test_symspace', 'test_testing', 'test_symProjectTestsuite.mop')
        found_test_files = SymXmlTestRunner.discover(path)

        if expected_file not in found_test_files:
            self.fail('Expected test ({}) not found!'.format(expected_file))

    def test_run(self):
        path = os.path.join(symspace_home, 'System', 'Python', 'tests')
        tmp_dir = tempfile.mkdtemp()

        xmlTestRunner = SymXmlTestRunner(path, tmp_dir)
        xmlTestRunner.suppress_output = True
        xmlTestRunner.run()
        if show_html_report:
            xmlTestRunner.getHTMLReport(show=True)

        files = glob.glob(os.path.join(tmp_dir, '**junit.xml'))
        n_expected_errors = 2

        if len(files) < 1:
            self.fail('No unittest xml found!')

        n_testsuites = 0
        for file in files:
            with open(file, 'r') as fh:
                lines = fh.readlines()

            for line in lines:
                if line.startswith('<testsuite'):
                    n_testsuites += 1
                    self.assertEqual('<testsuite errors="{:d}" failures="0"'.format(n_expected_errors), line[:34])

        if n_testsuites < 1:
            self.fail('No testsuites found in xml!')


if __name__ == '__main__':
    from lcm.utils.testing import runUnittest

    runUnittest(getInterpreter())
