/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9720 $
 * $Date: 2020-03-19 15:59:49 +0100 (Thu, 19 Mar 2020) $
 */
package jobmanager.server.gui;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;

import javax.swing.JMenuItem;
import javax.swing.JPopupMenu;
import javax.swing.KeyStroke;

/**
 * Popup-menu for job-list
 * 
 * @author Werner Koppelsttter
 */
class JobListPopupMenu extends JPopupMenu {
	/** Serialization version number */
	private static final long serialVersionUID = 1L;
	/** view of jobmanager */
	JobManagerView view;

	/**
	 * Create a popmenu for job-list
	 * 
	 * @param view
	 *            View of jobmanager
	 */
	public JobListPopupMenu(JobManagerView view) {
		JMenuItem menu;
		boolean enable;

		enable = view.table.getSelectedRow() != -1;
		this.view = view;

		// Stop menu item
		menu = new JMenuItem("Stop");
		menu.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_S, 0));
		menu.addActionListener(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent e) {
				JobListPopupMenu.this.view.stopSelected();
			}
		});
		menu.setEnabled(enable);
		this.add(menu);

		// restart menu item
		menu = new JMenuItem("Restart");
		menu.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_R, 0));
		menu.addActionListener(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent e) {
				JobListPopupMenu.this.view.restartSelected();
			}
		});
		menu.setEnabled(enable);
		this.add(menu);

		// restart on cluster menu item
		menu = new JMenuItem("Restart Cluster");
		menu.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_C, 0));
		menu.addActionListener(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent e) {
				JobListPopupMenu.this.view.restartClusterSelected();
			}
		});
		menu.setEnabled(enable);
		this.add(menu);

		// restart local menu item
		menu = new JMenuItem("Restart Local");
		menu.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_L, 0));
		menu.addActionListener(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent e) {
				JobListPopupMenu.this.view.restartLocalSelected();
			}
		});
		menu.setEnabled(enable);
		this.add(menu);

		// remove menu item
		menu = new JMenuItem("Remove");
		menu.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_DELETE, 0));
		menu.addActionListener(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent e) {
				JobListPopupMenu.this.view.removeSelected();
			}
		});
		menu.setEnabled(enable);
		this.add(menu);

		// seperator
		this.addSeparator();

		// open directory menu item
		menu = new JMenuItem("Open working directory");
		menu.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_E, 0));
		menu.addActionListener(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent e) {
				JobListPopupMenu.this.view.openDirectory();
			}
		});
		menu.setEnabled(enable);
		this.add(menu);

		// seperator
		this.addSeparator();

		// refresh menu item
		menu = new JMenuItem("Refresh");
		menu.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_F5, 0));
		menu.addActionListener(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent e) {
				JobListPopupMenu.this.view.refresh();
			}
		});
		this.add(menu);

	}

}
